##########################################
## Cosmetics Europe Skin Sensitization
## Defined Approach Evaluation
## Nicole Kleinstreuer
## nicole.kleinstreuer@nih.gov
##
## BASF 2 out of 3 
## Bauch et al. 2012
## Urbisch et al. 2015
##
##Replace ".MNC" with ".GM" or appropriate metric to change LLNA EC3 summary comparison
##########################################

rm(list=ls())
date.string<-Sys.Date()
##Change directory string 
CE.dir <- "C:/Users/Nicole/Documents/Cosmetics Europe/"
setwd(CE.dir)

library(gdata)
library(caret)
library(e1071)

##########################################
#Read Cosmetic Europe in vitro data
CE<-read.table("CosEU_invitro_insilico_128chems_Jan2017.txt",header=TRUE,sep="\t")
CE$CASRN<-trim(CE$CASRN)
CE<-CE[order(CE$Num),]

##########################################
#Read in vivo LLNA and human data
IV<-read.table("CosEU_invivo_128chems_March2017.txt",header=TRUE,sep="\t")
IV$CASRN<-trim(IV$CASRN)
IV<-IV[order(IV$Num),]

##########################################
##Read data from Urbisch et al. 2015
#UDB<-read.table("Urbisch_chems.txt",header=TRUE,sep="\t")
##Look for overlap
#UDB$CASRN<-trim(UDB$CASRN)
#length(intersect(CE$CASRN,UDB$CASRN))
##91 chemicals overlap with the set of 128

##########################################
#Apply BASF IATA
#2 out of 3: DPRA,KeratinoSens,hCLAT
CE$Assays.Pos.DKH<-rowSums(CE[,c("DPRA.Call","KS.Call","hCLAT.Call")],na.rm=T)
CE$BASF.Call.DKH<-0
CE$BASF.Call.DKH[CE$Assays.Pos.DKH>1]<-1
CE$BASF.Call.DKH[which(is.na(CE$DPRA.Call) | is.na(CE$KS.Call) | is.na(CE$hCLAT.Call))] <- NA

#2 out of 3: DPRA,KeratinoSens,U-SENS
CE$Assays.Pos.DKU<-rowSums(CE[,c("DPRA.Call","KS.Call","U.SENS.Call")],na.rm=T)
CE$BASF.Call.DKU<-0
CE$BASF.Call.DKU[CE$Assays.Pos.DKU>1]<-1
CE$BASF.Call.DKU[which(is.na(CE$DPRA.Call) | is.na(CE$KS.Call) | is.na(CE$U.SENS.Call))] <- NA

##########################################
#Results for all chemicals (n=127 DKH, n=126 DKU)
#Create confusion matrix to compare in vitro call and LLNA result
confusionMatrix(data=CE$BASF.Call.DKH, reference=IV$LLNA.Call.MNC, positive="1")
confusionMatrix(data=CE$BASF.Call.DKU, reference=IV$LLNA.Call.MNC, positive="1")
#Create confusion matrix to compare in vitro call and human result
confusionMatrix(data=CE$BASF.Call.DKH, reference=IV$human.Call, positive="1")
confusionMatrix(data=CE$BASF.Call.DKU, reference=IV$human.Call, positive="1")

##########################################
#Results for "test set" chemicals (n=36 DKH, n=35 DKU)
CEt<-CE[CE$CASRN %in% setdiff(CE$CASRN,UDB$CASRN),]
IVt<-IV[IV$CASRN %in% setdiff(CE$CASRN,UDB$CASRN),]
#Create confusion matrix to compare in vitro call and LLNA result
confusionMatrix(data=CEt$BASF.Call.DKH, reference=IVt$LLNA.Call.MNC, positive="1")
confusionMatrix(data=CEt$BASF.Call.DKU, reference=IVt$LLNA.Call.MNC, positive="1")
#Create confusion matrix to compare in vitro call and human result
confusionMatrix(data=CEt$BASF.Call.DKH, reference=IVt$human.Call, positive="1")
confusionMatrix(data=CEt$BASF.Call.DKU, reference=IVt$human.Call, positive="1")

##########################################
#Mark overlap set chemicals
CE$BASF_Overlap<-0
CE$BASF_Overlap[CE$CASRN %in% intersect(CE$CASRN,UDB$CASRN)]<-1
