##########################################
## Cosmetics Europe Skin Sensitization
## Defined Approach Evaluation
## Nicole Kleinstreuer
## nicole.kleinstreuer@nih.gov
##
##Create detailed performance statistics for all defined approaches
##
##############################################################

install.packages("caret")
library(caret)

##Read in the matrix of data and DA predictions
CE<-read.table("Kleinstreuer_etal_Supp Table 2_All_invitro_invivo_insilico_DApredictions_1Dec2017.txt",header=TRUE,sep="\t")

##HAZARD
##Change variable below to one of the DA hazard predictions
##"BASF.Call.DKH","Kao.STS.Call","Kao.ITS2015.Call","Kao.ITS2013.Call","ANN_Model1_Call","ANN_Model4_Call","ICCVAM_SVM_LLNA_Call","ICCVAM_SVM_Human_Call","BN.ITS3.Hazard.Call"
DA<-"BN.ITS3.Hazard.Call"

##Human hazard comparison  
confusionMatrix(data=CE[,DA], reference=CE$human_Call, positive="1")

##LLNA hazard comparison  
confusionMatrix(data=CE[,DA], reference=CE$LLNA_Call_MNC, positive="1")

##POTENCY
##Human based on Basketter categories (1 is Extreme, 2 is strong, 3 is Moderate, 4 is Weak, 5 and 6 are Non)
##LLNA based on median with negative conisderation (MNC)

##Change variable below to one of the DA potency predictions
##"Kao.STS.Pot","Kao.ITS2015.Pot","Kao.ITS2013.Pot","ANN_Model1_Potency_Pred.3class","ANN_Model4_Potency_Pred.3class","BN.ITS3.Potency.3class"
DA<-"BN.ITS3.Potency.3class"

##Order potency classes
CE[,DA]<-factor(CE[,DA], levels=c("Non","Weak","Strong"))
CE$human_potency_3class<-factor(CE$human_potency_3class, levels=c("Non","Weak","Strong"))
CE$LLNA_potency_3class_MNC<-factor(CE$LLNA_potency_3class_MNC, levels=c("Non","Weak","Strong"))

##Human potency comparison  
confusionMatrix(data=CE[,DA], reference=CE$human_potency_3class)

##LLNA potency comparison  
confusionMatrix(data=CE[,DA], reference=CE$LLNA_potency_3class_MNC)

##############################################################
##
##DA-specific non-overlapping sets
##
##############################################################


##HAZARD
##Change variable below to one of the DA hazard predictions
##"BASF.Call.DKH","Kao.STS.Call","Kao.ITS2015.Call","Kao.ITS2013.Call","ANN_Model1_Call","ANN_Model4_Call","ICCVAM_SVM_LLNA_Call","ICCVAM_SVM_Human_Call","BN.ITS3.Hazard.Call"
DA<-"BN.ITS3.Hazard.Call"

##Confine to non-overlapping test set - change variable below to DA training set overlap
##"BASF_Overlap","Kao.ITS_Overlap","Kao.STS_Overlap","ANN_Model1_Overlap","ANN_Model4_Overlap","ICCVAM_LLNA_Overlap","ICCVAM_Human_Overlap","BN.ITS3.Training.set_Overlap"
CEtest<-CE[CE$BN.ITS3.Training.set_Overlap==0,]

##Human hazard comparison  
confusionMatrix(data=CEtest[,DA], reference=CEtest$human_Call, positive="1")

##LLNA hazard comparison  
confusionMatrix(data=CEtest[,DA], reference=CEtest$LLNA_Call_MNC, positive="1")

##POTENCY
##Human based on Basketter categories (1 is Extreme, 2 is strong, 3 is Moderate, 4 is Weak, 5 and 6 are Non)
##LLNA based on median with negative conisderation (MNC)

##Change variable below to one of the DA potency predictions
##"Kao.STS.Pot","Kao.ITS2015.Pot","Kao.ITS2013.Pot","ANN_Model1_Potency_Pred.3class","ANN_Model4_Potency_Pred.3class","BN.ITS3.Potency.3class"
DA<-"BN.ITS3.Potency.3class"

##Order potency classes
CEtest[,DA]<-factor(CEtest[,DA], levels=c("Non","Weak","Strong"))
CEtest$human_potency_3class<-factor(CEtest$human_potency_3class, levels=c("Non","Weak","Strong"))
CEtest$LLNA_potency_3class_MNC<-factor(CEtest$LLNA_potency_3class_MNC, levels=c("Non","Weak","Strong"))

##Human potency comparison  
confusionMatrix(data=CEtest[,DA], reference=CEtest$human_potency_3class)

##LLNA potency comparison  
confusionMatrix(data=CEtest[,DA], reference=CEtest$LLNA_potency_3class_MNC)



##############################################################
##Alternate human classification 
##Basketter categories (1 is Extreme, 2 is strong, 3 is Moderate, 4 and 5 are Weak, 6 is Non)
##
##############################################################

##Change variable below to one of the DA potency predictions
##"Kao.STS.Pot","Kao.ITS2015.Pot","Kao.ITS2013.Pot","ANN_Model1_Potency_Pred.3class","ANN_Model4_Potency_Pred.3class","BN.ITS3.Potency.3class"
DA<-"BN.ITS3.Potency.3class"

##Order potency classes
CE[,DA]<-factor(CE[,DA], levels=c("Non","Weak","Strong"))
CE$human_potency_3class_alt<-factor(CE$human_potency_3class_alt, levels=c("Non","Weak","Strong"))

##Human potency comparison  
confusionMatrix(data=CE[,DA], reference=CE$human_potency_3class_alt)
